/*
 * display.h - Hifidelio display access.
 *
 * Copyright (C) 2006 - 2008 Andreas Scherrer, www.hifidelio-user.de
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

/**
 * \file display.h
 * Hifidelio display access.
 */

#ifndef _DISPLAY_H_
#define _DISPLAY_H_

#include <linux/fb.h>

/**
 * Default display foreground color.
 */
#define DISPLAY_FORE_COLOR 0x00000000

/**
 * Default display background color.
 */
#define DISPLAY_BACK_COLOR 0x99c0bf00

/**
 * Display width in pixels.
 */
#define DISPLAY_WIDTH 400

/**
 * Display height in pixels.
 */
#define DISPLAY_HEIGHT 160

/**
 * Number of bytes per display row.
 */
#define DISPLAY_WIDTH_BYTES 50

/**
 * Rectangular region on the display.
 */
struct display_region {
	int x1; /**< Upper left  x-coordinate of display region. */
	int y1; /**< Upper left  y-coordinate of display region. */
	int x2; /**< Lower right x-coordinate of display region. */
	int y2; /**< Lower right y-coordinate of display region. */
};

/**
 * Display data, including the display buffer and update regions.
 */
struct display_data {
	struct fb_var_screeninfo info;          /**< Framebuffer device information. */
	unsigned char *display_buffer;          /**< Display buffer. */
	int update_regions_count;               /**< Number of update regions. */
	struct display_region **update_regions; /**< Update regions. */
};

/*
 * Module functions.
 */
struct display_data *display_get_data();
int display_show_message(char *message, int duration);
int display_update(struct display_data *data);
void display_cleanup(struct display_data *data); 

#endif /* !_DISPLAY_H_ */

